/* -*-c-*-
 *
 * Common functionality of a less principled nature
 *
 * (c) 2020 Mark Wooding
 */

/*----- Licensing notice --------------------------------------------------*
 *
 * This file is part of Runlisp, a tool for invoking Common Lisp scripts.
 *
 * Runlisp is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 3 of the License, or (at your
 * option) any later version.
 *
 * Runlisp is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Runlisp.  If not, see <https://www.gnu.org/licenses/>.
 */

#ifndef COMMON_H
#define COMMON_H

#ifdef __cplusplus
  extern "C" {
#endif

/*----- Externally defined types ------------------------------------------*/

struct dstr;
struct argv;

/*----- Public variables --------------------------------------------------*/

extern struct config config;
extern struct config_section *toplevel, *builtin, *common, *env;
extern unsigned verbose;

/*----- Functions provided ------------------------------------------------*/

extern const char *my_getenv(const char */*name*/, const char */*dflt*/);
extern long parse_int(const char */*what*/, const char */*p*/,
		      long /*min*/, long /*max*/);
extern void argv_string(struct dstr */*d*/, const struct argv */*av*/);

#define FEF_EXEC 1u
#define FEF_VERBOSE 2u
extern int file_exists_p(const char */*path*/, unsigned /*f*/);
extern int found_in_path_p(const char */*prog*/, unsigned /*f*/);

#define TEF_DRYRUN 1u
#define TEF_VERBOSE 2u
extern int try_exec(struct argv */*av*/, unsigned /*f*/);

extern void read_config_file(const char */*what*/,
			     const char */*file*/, unsigned /*f*/);
extern void read_config_dir(const char */*what*/,
			    const char */*path*/, unsigned /*f*/);
extern void read_config_path(const char */*path*/, unsigned /*f*/);
extern int set_config_var(const char */*assign*/);
extern void init_config(void);
extern void load_default_config(void);
extern void dump_config(void);

/*----- That's all, folks -------------------------------------------------*/

#ifdef __cplusplus
  }
#endif

#endif
